@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Package-Version: 20260125.1207
-;; Package-Revision: 8d9a1646fb40
+;; Package-Version: 20260220.1157
+;; Package-Revision: 7120539bf047
 ;; Package-Requires: ((emacs "29.1") (compat "30"))
 ;; URL: https://github.com/minad/tempel
 ;; Keywords: abbrev, languages, tools, text
@@ -274,7 +274,10 @@ BEG and END are the boundaries of the modification."
         (save-excursion
           (goto-char (overlay-start ov))
           (when-let* ((str (if-let* ((form (overlay-get ov 'tempel--form)))
-                               (eval form (cdr st))
+                               ;; Ignore errors since variables may not be defined yet.
+                               (condition-case nil
+                                   (eval form (cdr st))
+                                 (void-variable ""))
                              (when-let* ((name (overlay-get ov 'tempel--name)))
                                (alist-get name (cdr st))))))
             (tempel--sync-replace (overlay-start ov)
